from .base import (
    BASE_EVENT_HANDLER
)

class DEFAULT_HANDLER(BASE_EVENT_HANDLER):
    pass
    

class MESSAGE_NEW(DEFAULT_HANDLER):
    pass

class MESSAGE_REPLY(DEFAULT_HANDLER):
    pass

class MESSAGE_EDIT(DEFAULT_HANDLER):
    pass

class MESSAGE_TYPING_STATE(DEFAULT_HANDLER):
    pass

class MESSAGE_READ(DEFAULT_HANDLER):
    pass

class MESSAGE_EVENT(DEFAULT_HANDLER):
    pass
    

class PHOTO_NEW(DEFAULT_HANDLER):
    pass

class PHOTO_COMMENT_NEW(DEFAULT_HANDLER):
    pass

class PHOTO_COMMENT_EDIT(DEFAULT_HANDLER):
    pass

class PHOTO_COMMENT_RESTORE(DEFAULT_HANDLER):
    pass

class PHOTO_COMMENT_DELETE(DEFAULT_HANDLER):
    pass


class AUDIO_NEW(DEFAULT_HANDLER):
    pass


class VIDEO_NEW(DEFAULT_HANDLER):
    pass

class VIDEO_COMMENT_NEW(DEFAULT_HANDLER):
    pass

class VIDEO_COMMENT_EDIT(DEFAULT_HANDLER):
    pass

class VIDEO_COMMENT_RESTORE(DEFAULT_HANDLER):
    pass

class VIDEO_COMMENT_DELETE(DEFAULT_HANDLER):
    pass


class WALL_POST_NEW(DEFAULT_HANDLER):
    pass

class WALL_REPOST(DEFAULT_HANDLER):
    pass

class WALL_SCHEDULE_POST_NEW(DEFAULT_HANDLER):
    pass

class WALL_SCHEDULE_POST_DELETE(DEFAULT_HANDLER):
    pass

class WALL_REPLY_NEW(DEFAULT_HANDLER):
    pass

class WALL_REPLY_EDIT(DEFAULT_HANDLER):
    pass

class WALL_REPLY_RESTORE(DEFAULT_HANDLER):
    pass

class WALL_REPLY_DELETE(DEFAULT_HANDLER):
    pass


class LIKE_ADD(DEFAULT_HANDLER):
    pass

class LIKE_REMOVE(DEFAULT_HANDLER):
    pass


class MARKET_COMMENT_NEW(DEFAULT_HANDLER):
    pass

class MARKET_COMMENT_EDIT(DEFAULT_HANDLER):
    pass

class MARKET_COMMENT_RESTORE(DEFAULT_HANDLER):
    pass

class MARKET_COMMENT_DELETE(DEFAULT_HANDLER):
    pass

class MARKET_ORDER_NEW(DEFAULT_HANDLER):
    pass

class MARKET_ORDER_EDIT(DEFAULT_HANDLER):
    pass


class GROUP_LEAVE(DEFAULT_HANDLER):
    pass

class GROUP_JOIN(DEFAULT_HANDLER):
    pass

class USER_BLOCK(DEFAULT_HANDLER):
    pass

class USER_UNBLOCK(DEFAULT_HANDLER):
    pass


class POLL_VOTE_NEW(DEFAULT_HANDLER):
    pass

class GROUP_OFFICERS_EDIT(DEFAULT_HANDLER):
    pass

class GROUP_CHANGE_SETTINGS(DEFAULT_HANDLER):
    pass

class GROUP_CHANGE_PHOTO(DEFAULT_HANDLER):
    pass

class VKPAY_TRANSACTION(DEFAULT_HANDLER):
    pass